.. documentation master file, created by sphinx-quickstart on 
   Tue Jul  9 22:26:36 2013. You can adapt this file completely to your liking,
   but it should at least contain the root `toctree` directive.

pyeasyga
==================================================

*A simple and easy-to-use Genetic Algorithm implementation library in Python*

**Contents:**

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
